==> haskell-mysql-simple-0.4.9-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-9mNA2gNmC7w7j89uqpMaDS
key:                  mysql-simple-0.4.9-9mNA2gNmC7w7j89uqpMaDS
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  345325271676a2e41af48618a8277c3c
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-9mNA2gNmC7w7j89uqpMaDS
depends:
    attoparsec-0.14.4-21g0xvIiXNtBpdLdrKPYdv base-4.17.2.1
    base16-bytestring-1.0.2.0-LZWoqVsRU525spGmpCza2K
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-Lr10t2QdDGxFoSU8x9jsZQ
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W text-2.0.2 time-1.12.2
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.9-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-F2krDOGvqYeDTJa795uD2k
key:                  mysql-simple-0.4.9-F2krDOGvqYeDTJa795uD2k
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  4740c0af175fd25c4c835e543d5fa126
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-F2krDOGvqYeDTJa795uD2k
depends:
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    base16-bytestring-1.0.2.0-IEtpsrDkMVlLM4YsQhzHqm
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-3BhwdApYSM13Oy5kQSRzCf
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W text-2.0.2 time-1.12.2
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
